@@ -1,4 +1,6 @@
 import re
+import uuid
+
 
 def get_re_first(pattern, string, flags=0):
     """
@@ -12,6 +14,11 @@ def get_re_first(pattern, string, flags=0):
     return r.group()
 
 
+def get_re_first_subs(pattern, string, flags=0):
+    r = re.search(pattern, string, flags)
+    return r.groups()
+
+
 def get_re_all(pattern, string, flags=0):
     r = re.findall(pattern, string, flags)
     return r
@@ -21,4 +28,5 @@ def get_re_last(pattern, string, flags=0):
     return get_re_all(pattern, string, flags)[-1]
 
 
-
+def rand_hex32():
+    return uuid.uuid4().hex
