@@ -33,12 +33,20 @@ def md5(data):
     return m.hexdigest()
 
 
+def json_dump(data):
+    return json.dumps(data, indent=4)
+
+
 def print_json(data):
-    print(json.dumps(data, indent=4))
+    print(json_dump(data))
 
 
 def get_timestamp13():
-    return int(time.time() * 1000)
+    return str(int(time.time() * 1000))
+
+
+def get_timestamp10():
+    return str(int(time.time()))
 
 
 def read_file(file_path, mode="r"):
